@@ -1,5 +1,5 @@
 from dockitcms.viewpoints.forms import TemplateFormMixin
-from dockitcms.viewpoints.common import CanonicalMixin, AuthenticatedMixin, TemplateMixin
+from dockitcms.viewpoints.common import CanonicalMixin, TemplateMixin
 
 from common import CollectionMixin, PointListView, PointDetailView
 
@@ -11,13 +11,10 @@ from dockit.forms import DocumentForm
 from django.conf.urls.defaults import patterns, url
 from django.utils.translation import ugettext_lazy as _
 
-class BaseCollectionViewPoint(CollectionMixin, TemplateMixin, AuthenticatedMixin, ViewPoint):
-    view_type = ViewPoint._meta.fields['view_type'] #hack around
+class BaseCollectionViewPoint(ViewPoint, CollectionMixin, TemplateMixin):
     view_class = None
     
     class Meta:
-        typed_field = 'view_type'
-        collection = ViewPoint._meta.collection
         proxy = True
     
     @classmethod
@@ -53,7 +50,7 @@ class CollectionListViewPoint(BaseCollectionViewPoint):
     class Meta:
         typed_key = 'dockitcms.collectionlistview'
 
-class CollectionDetailViewPoint(CanonicalMixin, BaseCollectionViewPoint):
+class CollectionDetailViewPoint(BaseCollectionViewPoint, CanonicalMixin):
     slug_field = schema.SlugField(blank=True)
     
     view_class = PointDetailView
