@@ -6,7 +6,7 @@ from classytags.core import Options
 from classytags.helpers import InclusionTag
 from classytags.arguments import Argument
 
-from dockitcms.scope import get_site_scope
+import collections
 
 class WidgetBlock(InclusionTag):
     name = 'widgetblock'
@@ -20,15 +20,15 @@ class WidgetBlock(InclusionTag):
         if 'scopes' in context:
             scopes = context['scopes']
         else:
-            scopes = [get_site_scope()]
+            return []
+            #TODO possibly use DefaultScopeMiddleware to populate this
         for scope in scopes:
-            if 'object' in scope.kwargs:
-                obj = scope.kwargs['object']
+            if 'widgets' in scope.data:
                 scope_widgets = list()
-                if hasattr(obj, '_widgets'):
-                    for widget in obj._widgets:
-                        if widget.block_key == block_key:
-                            scope_widgets.append(widget)
+                for widget in scope.data['widgets'].data:
+                    if widget.block_key == block_key:
+                        widget.scope = scope
+                        scope_widgets.append(widget)
                 if scope_widgets: #TODO how to properly merge
                     widgets.extend(scope_widgets)
         return widgets
@@ -41,3 +41,20 @@ class WidgetBlock(InclusionTag):
                 'block_key':block_key,}
 
 register.tag(WidgetBlock)
+
+class RenderWidgets(InclusionTag):
+    name = 'renderwidgets'
+    template = 'widgetblock/widget_holder.html'
+    options = Options(
+        Argument('widgets', resolve=True),
+    )
+        
+    def get_context(self, context, widgets):
+        if not isinstance(widgets, collections.Iterable):
+            widgets = [widgets]
+        for widget in widgets:
+            widget.rendered_content = widget.render(context)
+        return {'widgets':widgets,}
+
+register.tag(RenderWidgets)
+
